==> jc-1.4.0.tar.gz: javax/swing/text/StringContent__24RemoveUndo.h <==
// class javax.swing.text.StringContent$RemoveUndo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ac31e019afa1437d javax_swing_text_StringContent__24RemoveUndo
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit

// header file dependencies
// @dep_header javax_swing_undo_AbstractUndoableEdit

#include "javax/swing/undo/AbstractUndoableEdit.h"

#ifndef _JC_javax_swing_text_StringContent__24RemoveUndo_H_
#define _JC_javax_swing_text_StringContent__24RemoveUndo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_StringContent$object;

// Typedefs
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$sub_refs	_jc_javax_swing_text_StringContent__24RemoveUndo$sub_refs;
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$sub_nonrefs	_jc_javax_swing_text_StringContent__24RemoveUndo$sub_nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$refs	_jc_javax_swing_text_StringContent__24RemoveUndo$refs;
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$nonrefs	_jc_javax_swing_text_StringContent__24RemoveUndo$nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$object	_jc_javax_swing_text_StringContent__24RemoveUndo$object;

typedef const struct _jc_javax_swing_text_StringContent__24RemoveUndo$vmethods	_jc_javax_swing_text_StringContent__24RemoveUndo$vmethods;
typedef const struct _jc_javax_swing_text_StringContent__24RemoveUndo$vtable	_jc_javax_swing_text_StringContent__24RemoveUndo$vtable;
typedef const struct _jc_javax_swing_text_StringContent__24RemoveUndo$vtype	_jc_javax_swing_text_StringContent__24RemoveUndo$vtype;

// Constructors
extern void _jc_javax_swing_text_StringContent__24RemoveUndo$method$_init$a967983a72111259(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *, struct _jc_javax_swing_text_StringContent$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_javax_swing_text_StringContent__24RemoveUndo$method$redo$25b0fd1adab70c30(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *);
extern void _jc_javax_swing_text_StringContent__24RemoveUndo$method$undo$2a1fa1bb5289512f(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StringContent__24RemoveUndo$method_info$redo$25b0fd1adab70c30;
extern _jc_method _jc_javax_swing_text_StringContent__24RemoveUndo$method_info$undo$2a1fa1bb5289512f;

// Virtual methods structure
struct _jc_javax_swing_text_StringContent__24RemoveUndo$vmethods {
	void	(*redo$25b0fd1adab70c30)(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *);
	void	(*undo$2a1fa1bb5289512f)(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *);
};

// Vtable
struct _jc_javax_swing_text_StringContent__24RemoveUndo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_text_StringContent__24RemoveUndo$vmethods	javax_swing_text_StringContent__24RemoveUndo;
};

// Vtype
struct _jc_javax_swing_text_StringContent__24RemoveUndo$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StringContent__24RemoveUndo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24RemoveUndo$sub_refs {
	struct _jc_java_lang_String$object	*undoString;
	struct _jc_javax_swing_text_StringContent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24RemoveUndo$refs {
    _jc_javax_swing_text_StringContent__24RemoveUndo$sub_refs	javax_swing_text_StringContent__24RemoveUndo;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24RemoveUndo$sub_nonrefs {
	jint	start;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24RemoveUndo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_text_StringContent__24RemoveUndo$sub_nonrefs	javax_swing_text_StringContent__24RemoveUndo;
};

// Object instance structure
struct _jc_javax_swing_text_StringContent__24RemoveUndo$object {
	_jc_javax_swing_text_StringContent__24RemoveUndo$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StringContent__24RemoveUndo$vtype	*vtype;
	_jc_javax_swing_text_StringContent__24RemoveUndo$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StringContent__24RemoveUndo$vtype _jc_javax_swing_text_StringContent__24RemoveUndo$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StringContent__24RemoveUndo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StringContent__24RemoveUndo$class_object;

#endif	/* _JC_javax_swing_text_StringContent__24RemoveUndo_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/StringContent__24RemoveUndo.h <==
// class javax.swing.text.StringContent$RemoveUndo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a29e36ef9ee1cddb javax_swing_text_StringContent__24RemoveUndo
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit

// header file dependencies
// @dep_header javax_swing_undo_AbstractUndoableEdit

#include "javax/swing/undo/AbstractUndoableEdit.h"

#ifndef _JC_javax_swing_text_StringContent__24RemoveUndo_H_
#define _JC_javax_swing_text_StringContent__24RemoveUndo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_StringContent$object;

// Typedefs
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$sub_refs	_jc_javax_swing_text_StringContent__24RemoveUndo$sub_refs;
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$sub_nonrefs	_jc_javax_swing_text_StringContent__24RemoveUndo$sub_nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$refs	_jc_javax_swing_text_StringContent__24RemoveUndo$refs;
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$nonrefs	_jc_javax_swing_text_StringContent__24RemoveUndo$nonrefs;
typedef struct _jc_javax_swing_text_StringContent__24RemoveUndo$object	_jc_javax_swing_text_StringContent__24RemoveUndo$object;

typedef const struct _jc_javax_swing_text_StringContent__24RemoveUndo$vmethods	_jc_javax_swing_text_StringContent__24RemoveUndo$vmethods;
typedef const struct _jc_javax_swing_text_StringContent__24RemoveUndo$vtable	_jc_javax_swing_text_StringContent__24RemoveUndo$vtable;
typedef const struct _jc_javax_swing_text_StringContent__24RemoveUndo$vtype	_jc_javax_swing_text_StringContent__24RemoveUndo$vtype;

// Constructors
extern void _jc_javax_swing_text_StringContent__24RemoveUndo$method$_init$a967983a72111259(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *, struct _jc_javax_swing_text_StringContent$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_text_StringContent__24RemoveUndo$method$redo$25b0fd1adab70c30(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_StringContent__24RemoveUndo$method$undo$2a1fa1bb5289512f(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_StringContent__24RemoveUndo$method_info$redo$25b0fd1adab70c30;
extern _jc_method _jc_javax_swing_text_StringContent__24RemoveUndo$method_info$undo$2a1fa1bb5289512f;

// Virtual methods structure
struct _jc_javax_swing_text_StringContent__24RemoveUndo$vmethods {
	void	(*redo$25b0fd1adab70c30)(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *) _JC_JCNI_ATTR;
	void	(*undo$2a1fa1bb5289512f)(_jc_env *, struct _jc_javax_swing_text_StringContent__24RemoveUndo$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_StringContent__24RemoveUndo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_text_StringContent__24RemoveUndo$vmethods	javax_swing_text_StringContent__24RemoveUndo;
};

// Vtype
struct _jc_javax_swing_text_StringContent__24RemoveUndo$vtype {
	_jc_type			type;
	_jc_javax_swing_text_StringContent__24RemoveUndo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24RemoveUndo$sub_refs {
	struct _jc_java_lang_String$object	*undoString;
	struct _jc_javax_swing_text_StringContent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24RemoveUndo$refs {
    _jc_javax_swing_text_StringContent__24RemoveUndo$sub_refs	javax_swing_text_StringContent__24RemoveUndo;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_StringContent__24RemoveUndo$sub_nonrefs {
	jint	start;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_StringContent__24RemoveUndo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_text_StringContent__24RemoveUndo$sub_nonrefs	javax_swing_text_StringContent__24RemoveUndo;
};

// Object instance structure
struct _jc_javax_swing_text_StringContent__24RemoveUndo$object {
	_jc_javax_swing_text_StringContent__24RemoveUndo$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_StringContent__24RemoveUndo$vtype	*vtype;
	_jc_javax_swing_text_StringContent__24RemoveUndo$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_StringContent__24RemoveUndo$vtype _jc_javax_swing_text_StringContent__24RemoveUndo$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_StringContent__24RemoveUndo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_StringContent__24RemoveUndo$class_object;

#endif	/* _JC_javax_swing_text_StringContent__24RemoveUndo_H_ */
